@@ -77,8 +77,8 @@ class MainWindow(QtGui.QMainWindow):
         self.rangcounter=0
 #Buttons + Widgets Funktionszuordnung        
         self.ui.punktestand.setText("Punktestand: "+str(self.score)+" Falsche Antworten: "+str(self.niederlagencounter))
-        self.ui.beenden.clicked.connect(self.closefunc)
-        self.ui.close.clicked.connect(self.closefunc)
+        self.ui.beenden.clicked.connect(self.exit_nosave)
+        self.ui.close.clicked.connect(self.exit_save)
         self.ui.minimize.clicked.connect(self.minimizefunc)
         self.ui.neuesspiel.clicked.connect(self.neuesspiel)
         self.ui.beginnen.clicked.connect(self.spielstarten)
@@ -427,9 +427,11 @@ class MainWindow(QtGui.QMainWindow):
     def minimizefunc(self):#Experimentell, schließt statt zu minimieren
         subprocess.Popen(['dbus-send', '--type=signal', '--session', '/com/nokia/hildon_desktop', 'com.nokia.hildon_desktop.exit_app_view'])        
             
-    def closefunc(self):#Methode zum Schließen des Mainwindows
+    def exit_save(self):#Methode zum Schließen des Mainwindows
         self.save_settings()
         sys.exit()
+    def exit_nosave(self):#Methode zum Schließen des Mainwindows
+        sys.exit()    
         
     def sound(self):
         status=self.ui.sound.checkState()
